@@ -1,9 +1,9 @@
 package Music::ToRoman;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Convert chords to Roman numeral notation
+# ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0500';
 
 use Moo;
 use strictures 2;
@@ -98,10 +98,10 @@ sub parse {
     # Drop the minor and major part of the chord name
     $decorator =~ s/M//i;
 
-    if ( $decorator =~ /([A-G])/ ) {
+    if ( $decorator =~ /([A-G][#b]?)/ ) {
         my $letter = $1;
         $position = first_index { $_ eq $letter } @notes;
-        $decorator =~ s/[A-G]/$roman[$position]/;
+        $decorator =~ s/[A-G][#b]?/$roman[$position]/;
     }
 
     # Append the remaining decorator to the roman representation
@@ -120,11 +120,11 @@ __END__
 
 =head1 NAME
 
-Music::ToRoman - Convert chords to Roman numeral notation
+Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0400
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -156,6 +156,9 @@ version 0.0400
 C<Music::ToRoman> converts chords to Roman numeral notation.  Also individual
 "chordless" notes may be converted given a diatonic mode B<scale_name>.
 
+For example usage, check out the files F<eg/roman> and F<eg/basslines> in
+L<Music::BachChoralHarmony>.
+
 =head1 ATTRIBUTES
 
 =head2 scale_note
